import { createRoot } from "react-dom/client";
import SurveyComponent from "./SurveyComponent";

const container = document.getElementById("root");
const root = createRoot(container);
root.render(<SurveyComponent />);
